MCPcopy Create free account
hub / github.com/ComputationalRobotics/XM-code / dnmat_dot_kernel

Function dnmat_dot_kernel

XM/include/Dense/matdot.h:22–32  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

20 */
21template <typename T>
22__global__ void dnmat_dot_kernel(
23 T* dnmat3_vals, T* dnmat1_vals, T* dnmat2_vals,
24 size_s total_len, const size_s power
25) {
26 size_l idx = threadIdx.x + blockIdx.x * blockDim.x;
27 if (idx < total_len) {
28 if(power == 1) dnmat3_vals[idx] = dnmat1_vals[idx] * dnmat2_vals[idx];
29 else dnmat3_vals[idx] = dnmat1_vals[idx] * pow(dnmat2_vals[idx],power);
30 }
31 return;
32}
33
34// cpu function of Ddot
35template <typename T>

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected